==> knative-model-6.7.1-sources.jar: io/fabric8/knative/eventing/contrib/prometheus/v1alpha1/PrometheusSourceStatusBuilder.java <==
package io.fabric8.knative.eventing.contrib.prometheus.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class PrometheusSourceStatusBuilder extends PrometheusSourceStatusFluentImpl<PrometheusSourceStatusBuilder> implements VisitableBuilder<PrometheusSourceStatus,PrometheusSourceStatusBuilder>{
  public PrometheusSourceStatusBuilder() {
    this(false);
  }
  public PrometheusSourceStatusBuilder(Boolean validationEnabled) {
    this(new PrometheusSourceStatus(), validationEnabled);
  }
  public PrometheusSourceStatusBuilder(PrometheusSourceStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public PrometheusSourceStatusBuilder(PrometheusSourceStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new PrometheusSourceStatus(), validationEnabled);
  }
  public PrometheusSourceStatusBuilder(PrometheusSourceStatusFluent<?> fluent,PrometheusSourceStatus instance) {
    this(fluent, instance, false);
  }
  public PrometheusSourceStatusBuilder(PrometheusSourceStatusFluent<?> fluent,PrometheusSourceStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withAnnotations(instance.getAnnotations());
      fluent.withCeAttributes(instance.getCeAttributes());
      fluent.withConditions(instance.getConditions());
      fluent.withObservedGeneration(instance.getObservedGeneration());
      fluent.withSinkUri(instance.getSinkUri());
    }
    this.validationEnabled = validationEnabled; 
  }
  public PrometheusSourceStatusBuilder(PrometheusSourceStatus instance) {
    this(instance,false);
  }
  public PrometheusSourceStatusBuilder(PrometheusSourceStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withAnnotations(instance.getAnnotations());
      this.withCeAttributes(instance.getCeAttributes());
      this.withConditions(instance.getConditions());
      this.withObservedGeneration(instance.getObservedGeneration());
      this.withSinkUri(instance.getSinkUri());
    }
    this.validationEnabled = validationEnabled; 
  }
  PrometheusSourceStatusFluent<?> fluent;
  Boolean validationEnabled;
  public PrometheusSourceStatus build() {
    PrometheusSourceStatus buildable = new PrometheusSourceStatus(fluent.getAnnotations(),fluent.getCeAttributes(),fluent.getConditions(),fluent.getObservedGeneration(),fluent.getSinkUri());
    return buildable;
  }
  
}

==> knative-model-6.8.0-sources.jar: io/fabric8/knative/eventing/contrib/prometheus/v1alpha1/PrometheusSourceStatusBuilder.java <==
package io.fabric8.knative.eventing.contrib.prometheus.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class PrometheusSourceStatusBuilder extends PrometheusSourceStatusFluent<PrometheusSourceStatusBuilder> implements VisitableBuilder<PrometheusSourceStatus,PrometheusSourceStatusBuilder>{
  public PrometheusSourceStatusBuilder() {
    this(false);
  }
  public PrometheusSourceStatusBuilder(Boolean validationEnabled) {
    this(new PrometheusSourceStatus(), validationEnabled);
  }
  public PrometheusSourceStatusBuilder(PrometheusSourceStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public PrometheusSourceStatusBuilder(PrometheusSourceStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new PrometheusSourceStatus(), validationEnabled);
  }
  public PrometheusSourceStatusBuilder(PrometheusSourceStatusFluent<?> fluent,PrometheusSourceStatus instance) {
    this(fluent, instance, false);
  }
  public PrometheusSourceStatusBuilder(PrometheusSourceStatusFluent<?> fluent,PrometheusSourceStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new PrometheusSourceStatus());

    if (instance != null) {
      fluent.withAnnotations(instance.getAnnotations());
      fluent.withCeAttributes(instance.getCeAttributes());
      fluent.withConditions(instance.getConditions());
      fluent.withObservedGeneration(instance.getObservedGeneration());
      fluent.withSinkCACerts(instance.getSinkCACerts());
      fluent.withSinkUri(instance.getSinkUri());
      fluent.withAnnotations(instance.getAnnotations());
      fluent.withCeAttributes(instance.getCeAttributes());
      fluent.withConditions(instance.getConditions());
      fluent.withObservedGeneration(instance.getObservedGeneration());
      fluent.withSinkCACerts(instance.getSinkCACerts());
      fluent.withSinkUri(instance.getSinkUri());
    }
    this.validationEnabled = validationEnabled; 
  }
  public PrometheusSourceStatusBuilder(PrometheusSourceStatus instance) {
    this(instance,false);
  }
  public PrometheusSourceStatusBuilder(PrometheusSourceStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new PrometheusSourceStatus());

    if (instance != null) {
      this.withAnnotations(instance.getAnnotations());
      this.withCeAttributes(instance.getCeAttributes());
      this.withConditions(instance.getConditions());
      this.withObservedGeneration(instance.getObservedGeneration());
      this.withSinkCACerts(instance.getSinkCACerts());
      this.withSinkUri(instance.getSinkUri());
      this.withAnnotations(instance.getAnnotations());
      this.withCeAttributes(instance.getCeAttributes());
      this.withConditions(instance.getConditions());
      this.withObservedGeneration(instance.getObservedGeneration());
      this.withSinkCACerts(instance.getSinkCACerts());
      this.withSinkUri(instance.getSinkUri());
    }
    this.validationEnabled = validationEnabled; 
  }
  PrometheusSourceStatusFluent<?> fluent;
  Boolean validationEnabled;
  public PrometheusSourceStatus build() {
    PrometheusSourceStatus buildable = new PrometheusSourceStatus(fluent.getAnnotations(),fluent.buildCeAttributes(),fluent.buildConditions(),fluent.getObservedGeneration(),fluent.getSinkCACerts(),fluent.getSinkUri());
    return buildable;
  }
  
}
